@@ -72,9 +72,9 @@ GBSG2$grade.bin <- as.factor(as.numeric(GBSG2$tgrade!="I"))
 levels(GBSG2$grade.bin) <- c("I","II/III")
 
 d <- SimSurv(100)
-library(randomSurvivalForest)
+library(randomForestSRC)
 
-RSF=rsf(Survrsf(time,status)~age+tsize+grade.bin+pnodes+progrec+estrec,data=GBSG2,forest=TRUE)
+RSF=rfsrc(Surv(time,status)~age+tsize+grade.bin+pnodes+progrec+estrec,data=GBSG2,forest=TRUE)
 save(RSF,file="~/research/SoftWare/pec/exa/RSF-gbsg2.rda")
 set.seed(17)
 b632 <- pec.list(object=list(RSF),formula=Surv(time,status)~1,data=GBSG2,cens.model="marginal",splitMethod="boot632plus",B=10,M=500)
@@ -82,7 +82,7 @@ set.seed(17)
 b632a <- pec.list(object=list(RSF),noinf.permute=T,formula=Surv(time,status)~1,data=GBSG2,cens.model="marginal",splitMethod="boot632plus",B=10,M=500)
 plot(b632a$NoInfErr[[2]],b632$NoInfErr[[2]])
 
-f3 <- rsf(Survrsf(time,status)~X1+X2,data=d)
+f3 <- rfsrc(Survrsf(time,status)~X1+X2,data=d)
 set.seed(17)
 b632 <- pec.list(object=list(f3),formula=Surv(time,status)~1,data=d,cens.model="marginal",splitMethod="boot632plus",B=10)
 set.seed(17)
